Flood class

Simulated river discharge at 5 km resolution from 1984 up to 7 months forecast.

https://open-meteo.com/en/docs/flood-api/

Constructors

Flood({String apiUrl = 'https://flood-api.open-meteo.com/v1/', required double latitude, required double longitude, int? past_days, int? forecast_days, DateTime? start_date, DateTime? end_date, CellSelection? cell_selection, String? apikey})

Properties

apikey String?
Only required to commercial use to access reserved API resources for customers.
getter/setter pair
apiUrl String
Custom API URL, format: https://<domain>/<version>/.
getter/setter pair
cell_selection CellSelection?
Set a preference how grid-cells are selected.
getter/setter pair
end_date DateTime?
The time interval to get data. Data are available from 1984-01-01 until 7 month forecast.
getter/setter pair
ensemble bool?
If true, all forecast ensemble members will be returned.
getter/setter pair
forecast_days int?
Per default, only 92 days are returned. Up to 210 days of forecast are possible.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
latitude double
Geographical WGS84 coordinates of the location.
final
longitude double
Geographical WGS84 coordinates of the location.
final
past_days int?
If past_days is set, past weather data can be returned.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start_date DateTime?
The time interval to get data. Data are available from 1984-01-01 until 7 month forecast.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
raw_request({List<Daily>? daily}) Future<Map<String, dynamic>>
Create a HTTP request. The function will return JSON data as Map if successful.
request({List<Daily>? daily}) Future<WeatherResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited