VariableWithValues class

Constructors

VariableWithValues(List<int> bytes)
factory

Properties

aggregation → Aggregation
no setter
altitude → int
no setter
depth → int
no setter
depthTo → int
no setter
ensembleMember → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
pressureLevel → int
no setter
previousDay → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → Unit
no setter
value → double
no setter
values → List<double>?
no setter
valuesInt64 → List<int>?
no setter
variable → Variable
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

reader → const Reader<VariableWithValues>